from os.path import abspath, join
from dataclasses import dataclass
from typing import Optional
import activitysim.cli
from activitysim.core import inject, config
from activitysim.core.config import setting
from populationsim import steps  # This import is required!

@dataclass
class ActivitySimArgs(object):
    data: Optional[str] = None
    config: Optional[str] = None
    output: Optional[str] = None
    working_dir: Optional[str] = None
    settings_file: Optional[str] = None
    multiprocess: Optional[str] = None
    chunk_size: Optional[str] = None
    pipeline: Optional[str] = None
    resume: Optional[str] = None

curr_dir = abspath(__file__ + "/..")
config_dir = join(curr_dir, "configs")
controls_dir = join(curr_dir, "controls")
seed_dir = join(curr_dir, 'seeds')
output_dir = join(curr_dir, "output")

inject.add_injectable("configs_dir", str(config_dir))
inject.add_injectable("data_dir", str(controls_dir))
inject.add_injectable("output_dir", str(output_dir))

def update_table(table, replacements):
    for tablename, changes in replacements.items():
        if table["tablename"] == tablename:
            for field, new_value in changes.items():
                table[field] = new_value
    return table

# Setup the input tables for seed population
replacements = {
    "households": {"filename": join(seed_dir, "seed_households.csv")},
    "persons": {"filename": join(seed_dir, "seed_persons.csv")},
    "geo_cross_walk": {"filename": join(controls_dir, "geo_cross_walk.csv")},
}
input_tables = [update_table(t, replacements) for t in setting("input_table_list")]
config.override_setting("input_tables", input_tables)


assert inject.get_injectable("preload_injectables", None)
assert steps  # this assert is here to ensure that the import statement above (which does actual init work - sigh)
#               doesn't get "optimised" away in pycharm, and doesn't show up as a linting problem


activitysim.cli.run.run(ActivitySimArgs())

